API Reference
=============

.. automodule:: MoleCool

   
.. rubric:: Modules

.. autosummary::
   :toctree: generated/modules/
   :recursive:
   :caption: Modules

   spectra
   tools

.. rubric:: Classes

.. autosummary::
   :toctree: generated/classes/
   :recursive:
   :caption: Classes

   System.System
   Lasersystem.Lasersystem
   Lasersystem.Laser
   Levelsystem.Levelsystem
   Levelsystem.ElectronicState
   Levelsystem.ElectronicGrState
   Levelsystem.ElectronicExState
   Levelsystem.State
   Bfield.Bfield